@@ -1,3 +1,4 @@
+#![doc(html_root_url = "https://docs.rs/rustdx/0.2.2")]
 #![feature(test)]
 extern crate test;
 
@@ -12,16 +13,6 @@ pub mod serde_type;
 #[cfg(feature = "tcp")]
 pub mod tcp;
 
-// #[derive(Debug)]
-// pub enum Error {
-//     ArgsMissing,
-//     NotDir,
-//     FileNotFound,
-//     DataNotWritten,
-//     NotInitiated,
-//     BytesNotParsed,
-// }
-
 use thiserror::Error;
 
 #[derive(Error, Debug)]
